==> haskell-esqueleto-3.4.1.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 esqueleto
version:              3.4.1.0
visibility:           public
id:                   esqueleto-3.4.1.0-6uSiBTgOzSPL67mR32iIQL
key:                  esqueleto-3.4.1.0-6uSiBTgOzSPL67mR32iIQL
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  76256638c30b9d304f0ce33f975aad09
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.Internal.PersistentImport
    Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto

import-dirs:          /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/esqueleto-3.4.1.0
hs-libraries:         HSesqueleto-3.4.1.0-6uSiBTgOzSPL67mR32iIQL
depends:
    aeson-1.5.6.0-AbTDFQXjdUODhV2zVRkDXT
    attoparsec-0.13.2.5-GizkWPNym1tDxXu7xbn7bA base-4.14.1.0
    blaze-html-0.9.1.2-2yTsGIkXtmWB3Lt1pdMScK bytestring-0.10.12.0
    conduit-1.3.4.1-1jCUVqQRd77KYcBcbXkc8K containers-0.6.2.1
    monad-logger-0.3.36-KFKL45GNXue676zNa1Vdor
    persistent-2.11.0.2-LeJ7DyArS913e8MSJkwq2G
    resourcet-1.2.4.2-5f6n3flQq1pLZgZQ1NQBig
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unliftio-0.2.14-DB3eaazNkny74dKgO7b0Xk
    unordered-containers-0.2.13.0-8xrAhv2QGcsF4IHfxyp1m2

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-3.4.1.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 esqueleto
version:              3.4.1.0
visibility:           public
id:                   esqueleto-3.4.1.0-DAeikBOTC7F6lG03sofnCF
key:                  esqueleto-3.4.1.0-DAeikBOTC7F6lG03sofnCF
license:              BSD-3-Clause
copyright:            (c) 2012-2016 Felipe Almeida Lessa
maintainer:           cma@bitemyapp.com
author:               Felipe Lessa
homepage:             https://github.com/bitemyapp/esqueleto
synopsis:             Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.

    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)

    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.

    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.

category:             Database
abi:                  5a6ce243d09fc258b1ab7abb1585f522
exposed:              True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Experimental
    Database.Esqueleto.Internal.ExprParser
    Database.Esqueleto.Internal.Internal
    Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.PostgreSQL.JSON
    Database.Esqueleto.SQLite

hidden-modules:
    Database.Esqueleto.Internal.PersistentImport
    Database.Esqueleto.PostgreSQL.JSON.Instances Paths_esqueleto

import-dirs:          /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/esqueleto-3.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/esqueleto-3.4.1.0
hs-libraries:         HSesqueleto-3.4.1.0-DAeikBOTC7F6lG03sofnCF
depends:
    aeson-1.5.6.0-5UhD0HeD84KFPVsjqEyp8O
    attoparsec-0.13.2.5-J6b14THaxvY185NePfXLop base-4.14.1.0
    blaze-html-0.9.1.2-LrlSO9sOLE59wXedG2axxL bytestring-0.10.12.0
    conduit-1.3.4.1-BsPMp3atGtrJXb8lJ0hFF8 containers-0.6.2.1
    monad-logger-0.3.36-46McU0o6Jj7L5dT199GSxO
    persistent-2.11.0.4-1TDJozif1Rr7vvuIS88WCN
    resourcet-1.2.4.2-7jh3WeBmwav3Q3gOaWNv32
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unliftio-0.2.14-9ZkpadKoElZKW8c2tTXoSo
    unordered-containers-0.2.13.0-ApNkHwNvshX8NJ7lvcglMy

haddock-interfaces:   /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html:         /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
